@@ -1,5 +1,7 @@
+import numpy as np
+from typing import List
 from enum import Enum
-from abc import ABC
+from abc import ABC, abstractmethod
 from tictactoe.styledprint import Color, stylize
 
 
@@ -24,3 +26,22 @@ class Player(ABC):
         elif symbol == Symbol.o:
             color = Color.RED
         return stylize(symbol.name, color=color)
+
+    @abstractmethod
+    def action(self, state: np.ndarray, available_positions: List[int]) -> int:
+        pass
+
+    def on_new_action(self, state: np.ndarray):
+        pass
+
+    def on_win(self):
+        pass
+
+    def on_draw(self):
+        pass
+
+    def on_lose(self):
+        pass
+
+    def on_end(self):
+        pass
